package com.ruoyi.manage.service;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.manage.domain.ParameterSet;

import java.util.List;

/**
 * 参数设置Service接口
 * 
 * @author boman
 * @date 2025-06-18
 */
public interface IParameterSetService 
{
    /**
     * 查询参数设置
     * 
     * @param parameterId 参数设置主键
     * @return 参数设置
     */
    public ParameterSet selectParameterSetByParameterId(Long parameterId);

    /**
     * 查询参数设置列表
     * 
     * @param parameterSet 参数设置
     * @return 参数设置集合
     */
    public List<ParameterSet> selectParameterSetList(ParameterSet parameterSet);

    /**
     * 新增参数设置
     * 
     * @param parameterSet 参数设置
     * @return 结果
     */
    public AjaxResult insertParameterSet(ParameterSet parameterSet);

    /**
     * 修改参数设置
     * 
     * @param parameterSet 参数设置
     * @return 结果
     */
    public AjaxResult updateParameterSet(ParameterSet parameterSet);

    /**
     * 批量删除参数设置
     * 
     * @param parameterIds 需要删除的参数设置主键集合
     * @return 结果
     */
    public int deleteParameterSetByParameterIds(Long[] parameterIds);

    /**
     * 删除参数设置信息
     * 
     * @param parameterId 参数设置主键
     * @return 结果
     */
    public int deleteParameterSetByParameterId(Long parameterId);
}
